@@ -1,5 +1,4 @@
 import os
-import sys
 
 
 def common(**kwargs):
@@ -32,6 +31,7 @@ def common(**kwargs):
 
     AWS_S3_CUSTOM_DOMAIN = os.environ.get('AWS_S3_CUSTOM_DOMAIN', '')
     AWS_STORAGE_BUCKET_NAME = os.environ.get('AWS_STORAGE_BUCKET_NAME', '')
+    AWS_DEFAULT_ACL = 'public-read'
     AWS_ACCESS_KEY = os.environ.get('AWS_ACCESS_KEY', '')
     AWS_SECRET_KEY = os.environ.get('AWS_SECRET_KEY', '')
     AWS_ACCESS_KEY_ID = AWS_ACCESS_KEY
@@ -42,8 +42,6 @@ def common(**kwargs):
 
     TIME_ZONE = os.environ.get('TIME_ZONE', 'America/New_York')
 
-    RAVEN_DSN = os.environ.get('RAVEN_DSN', '')
-
     # -------------------------------------------
 
     DEBUG = False
@@ -61,7 +59,7 @@ def common(**kwargs):
 
     if AWS_S3_CUSTOM_DOMAIN:
         AWS_PRELOAD_METADATA = True
-        DEFAULT_FILE_STORAGE = 'storages.backends.s3boto.S3BotoStorage'
+        DEFAULT_FILE_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
         S3_URL = 'https://%s/' % AWS_S3_CUSTOM_DOMAIN
         # static data, e.g. css, js, etc.
         STATICFILES_STORAGE = 'cacheds3storage.CompressorS3BotoStorage'
@@ -72,12 +70,6 @@ def common(**kwargs):
         COMPRESS_URL = STATIC_URL
         COMPRESS_STORAGE = 'cacheds3storage.CompressorS3BotoStorage'
 
-    if RAVEN_DSN and 'migrate' not in sys.argv:
-        INSTALLED_APPS.append('raven.contrib.django.raven_compat')
-        RAVEN_CONFIG = {
-            'dsn': RAVEN_DSN,
-        }
-
     LOGGING = {
         'version': 1,
         'disable_existing_loggers': False,
