@@ -88,8 +88,7 @@ def common(**kwargs):
         },
     ]
 
-    # Django 1.x
-    MIDDLEWARE_CLASSES = [
+    MIDDLEWARE = [
         'django_statsd.middleware.GraphiteRequestTimingMiddleware',
         'django_statsd.middleware.GraphiteMiddleware',
         'django.middleware.common.CommonMiddleware',
@@ -99,9 +98,9 @@ def common(**kwargs):
         'django.contrib.messages.middleware.MessageMiddleware',
         'waffle.middleware.WaffleMiddleware',
         'impersonate.middleware.ImpersonateMiddleware',
+        'django.middleware.security.SecurityMiddleware',
+        'django.middleware.clickjacking.XFrameOptionsMiddleware'
     ]
-    # DJANGO 2.X
-    MIDDLEWARE = MIDDLEWARE_CLASSES
 
     ROOT_URLCONF = project + '.urls'
 
@@ -135,7 +134,7 @@ def common(**kwargs):
     THUMBNAIL_SUBDIR = "thumbs"
     EMAIL_SUBJECT_PREFIX = "[" + project + "] "
     EMAIL_HOST = 'localhost'
-    SERVER_EMAIL = project + "@ccnmtl.columbia.edu"
+    SERVER_EMAIL = project + "@mail.ctl.columbia.edu"
     DEFAULT_FROM_EMAIL = SERVER_EMAIL
 
     STATICMEDIA_MOUNTS = [
@@ -168,7 +167,12 @@ def common(**kwargs):
 
     SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTOCOL', 'https')
     SESSION_ENGINE = "django.contrib.sessions.backends.signed_cookies"
+
     SESSION_COOKIE_HTTPONLY = True
+    SESSION_COOKIE_SECURE = True
+
+    CSRF_COOKIE_SECURE = True
+    CSRF_COOKIE_HTTPONLY = True
 
     STATIC_ROOT = "/tmp/" + project + "/static"
     STATICFILES_DIRS = ["media/"]
